capture log close
set more off
clear
capture clear *
set mem 6g
global data "2010-08-06"
log using "cria ports_entry q", text replace

use ed${data}, clear

keep if ten<=(1/4)

egen c=count(fem), by(prof empresa ano q)
egen newhires=count(fem), by(empresa ano) 
gen percent_c=c/newhires
label var percent_c "% of new hires per occupation-firm-year"

sort empresa prof q ano


gen rembaseh=rembase/hnorm
egen mode_rembase=mode(rembase), by(empresa ano prof q) min
egen mode_rembaseh=mode(rembaseh), by(empresa ano prof q)  min
egen mode_remh=mode(remh), by(empresa ano prof q)  min

gen a=round(log(rembase),0.01)
egen mode_ln_rembase=mode(a), by(empresa ano prof q) 
gen b=round(log(rembaseh),0.01)
egen mode_ln_rembaseh=mode(b), by(empresa ano prof q) 
gen cc=round(log(remh),0.01)
egen mode_ln_remh=mode(cc), by(empresa ano prof q) 

gen rembase_equals_mode=(rembase>=0.95*mode_rembase & rembase<=1.05*mode_rembase)
gen remh_equals_mode=(remh>=0.95*mode_remh & remh<=1.05*mode_remh)
gen rembaseh_equals_mode=(rembaseh>=0.95*mode_rembaseh & rembaseh<=1.05*mode_rembaseh)

gen rembase_equals_mode2=(rembase>=0.9*mode_rembase & rembase<=1.1*mode_rembase) // estas linhas sao novas
gen remh_equals_mode2=(remh>=0.9*mode_remh & remh<=1.1*mode_remh)
gen rembaseh_equals_mode2=(rembaseh>=0.9*mode_rembaseh & rembaseh<=1.1*mode_rembaseh)

gen rembase_equals_ln_mode=(a==mode_ln_rembase)
gen rembaseh_equals_ln_mode=(b==mode_ln_rembaseh)
gen remh_equals_ln_mode=(cc==mode_ln_remh)
drop a b cc

collapse newhires c percent_c fem educ exp ten age pess  ///
	rembase rembaseh remh mode_rembase mode_rembaseh mode_remh mode_ln_rembase ///
	mode_ln_rembaseh mode_ln_remh rembase_equals_mode remh_equals_mode rembaseh_equals_mode ///
	rembase_equals_mode2 remh_equals_mode2 rembaseh_equals_mode2 /// 
	rembase_equals_ln_mode remh_equals_ln_mode rembaseh_equals_ln_mode ///
	(sd) sd_educ=educ sd_fem=fem sd_ten=ten sd_age=age sd_rembase=rembase ///
	sd_remh=remh sd_rembaseh=rembaseh, by(empresa ano prof q) // sect dist vendas capest qualif retirados
qui compress
su

sort ano
merge ano using d_ur_eurostat3
keep if _merge==3
ren ur current_U 
capture drop month 
drop _merge

sort empresa
merge empresa using c_empresa${data}
keep if _merge==3
drop _merge

egen sum_more10pc=sum(percent_c>=.1 & c>=3), by(empresa prof q) 
gen port_of_entry=(sum_more10pc>=c_empresa/2) // "occ-firm that hires >=10% of new entrants in >=(years in which firm available/2)"
gen port_of_entry_year=(percent_c>=.1 & c>=3 & port_of_entry==1) // "occ-firm-year that is port of entry"

keep if port_of_entry==1

gen ln_base_pay=log(rembase)
gen ln_hourly_base_pay=log(rembaseh)
gen ln_hourly_total_pay=log(remh)

gen cv_rembase= sd_rembase/rembase
gen cv_rembaseh= sd_rembaseh/rembaseh
gen cv_remh= sd_remh/remh

gen trend=ano-1982
gen trend2=trend^2
egen g=group(empresa prof q)
egen ccc=count(g), by(g ano)
drop if ccc==0
drop ccc

egen c_g=count(g), by(g)
egen min_ano_g=min(ano), by(g)
egen max_ano_g=max(ano), by(g)
egen gr=group(min_ano_g max_ano_g c_g)
egen c_gr=count(gr), by(gr)

egen index_cv_rembaseh=max((ano==1982)*cv_rembaseh), by(g)
egen index_ln_hourly_base_pay=max((ano==1982)* ln_hourly_total_pay), by(g)
egen index_c=max((ano==1982)*c), by(g)
gen c_index=c/index_c
gen cv_rembaseh_index=cv_rembaseh/index_cv_rembaseh
gen ln_hourly_base_pay_index=ln_hourly_base_pay/index_ln_hourly_base_pay

xtset g ano, yearly

gen ln_remh=log(remh)
gen ln_rembaseh=log(rembaseh)
gen ln_c=log(c) // nova - para analise da ciclicalidade
gen ln_educ=log(educ)
gen ln_exp=log(exp)
gen ln_age=log(age)

qui compress
save "ports_entry q ${data}", replace

log close
